#!/bin/sh

# check environment
function check_env()
{
	if [ ! -e /usr/bin/lscpu ]; then
		echo "/usr/bin/lscpu is not exists."
		return -1
	fi


	if [ ! -e /usr/sbin/lspci ]; then
		echo "/usr/sbin/lspci is not exists."
		return -1
	fi

	if [ ! -e /sys/class/infiniband/mlx5_0 ]; then
		echo "/sys/class/infiniband/mlx5_0 is not exists."
		return -1
	fi

	if [ ! -e /usr/bin/mlxfwreset ]; then
		echo "/usr/bin/mlxfwreset is not exists."
		return -1
	fi
	return 0
}
# check cpuinfo
function check_cpuinfo()
{
	LANG=c
	local ARCH=`lscpu|grep "^Architecture:"|cut -f 2 -d ":"|sed 's/^[ \t]*//'`
	local VENDOR=`lscpu|grep "^Vendor ID:"|cut -f 2 -d ":"|sed 's/^[ \t]*//'`
	local MODEL=`lscpu|grep "^Model:"|cut -f 2 -d ":"|sed 's/^[ \t]*//'`
	local STEPPING=`lscpu|grep "^Stepping:"|cut -f 2 -d ":"|sed 's/^[ \t]*//'`

	if [ x$ARCH != x"aarch64" ]; then
		echo "Architecture is not match"
		return -1
	fi

	if [ x$VENDOR != x"FUJITSU" -a x$VENDOR != x"0x46" ]; then
		echo "Vendor is not match"
		exit -1
	fi

	if [ x$MODEL != x"0" ]; then
		echo "Model is not match"
		return -1
	fi

	if [ x$STEPPING != x"0x1" ]; then
		echo "Stepping is not match"
		return -1
	fi
	return 0
}
# check IB
function check_ib()
{
	lspci -s 05:00.0 -xxx |grep -e "00: b3 15 1b 10" -e "00: b3 15 17 10"
	if [ $? -ne 0 ]; then
		echo "IB vender or device is not match"
		return -1
	fi
	return 0
}

# check IB linkup
#0 linkup
#1 not linkup
function check_ib_linkup()
{
	lspci -s 05:00.0 -xxx |grep "70: [0-9][0-9] [0-9][0-9] 03 11"
	return $?
}

# try to linkup
#0 mlxfwreset command successed
#1 mlxfwreset command failed
function try_to_linkup()
{
	local TRYCNT=3
	while [ $TRYCNT -ne 0 ];
	do
		mlxfwreset -y -d mlx5_0 -l 3 reset
		if [ $? -ne 0 ]; then
			echo "mlxfwreset command failed"	
			break
		fi	
		check_ib_linkup
		if [ $? -eq 0 ]; then
			exit 0
		else
			((TRYCNT--))
		fi
	done
	echo "IB LinkDegrade"	
	exit -1
}

check_env
if [ $? -ne 0 ]; then
	exit -1
fi
check_cpuinfo
if [ $? -ne 0 ]; then
	exit -1
fi
check_ib
if [ $? -ne 0 ]; then
	exit -1
fi
check_ib_linkup
if [ $? -eq 0 ]; then
	exit 0
else
	try_to_linkup
fi
